CoordPairExt extension

on

Properties

distance → num

Available on CoordPair, provided by the CoordPairExt extension

no setter

Methods

pointInBetween((num, num) ratio) → Coord

Available on CoordPair, provided by the CoordPairExt extension

Returns the point in between whose distance from first point and from second point is in the given ratio.