Angle class

Constructors

Angle.fromCoord(Coord coord)
factory
Angle.fromCos(num cosValue, [num denominator = 1])
factory
Angle.fromRadians(num radians)
factory
Angle.fromSides(num front, num base)
factory
Angle.fromSin(num sinValue, [num denominator = 1])
factory
Angle.fromTan(num tanValue, [num denominator = 1])
factory
Angle.fromTwoPoints(Coord first, Coord second)
factory
Angle.fromXY(num x, num y)
factory
Angle.raw(num front, num base)

Properties

a → num
If used as slope, then value of 'a' in eqn: ax + by + c = 0
no setter
abs → Angle
no setter
b → num
If used as slope, then value of 'b' in eqn: ax + by + c = 0
no setter
base → num
final
cosValue → num
no setter
flip → Angle
no setter
front → num
final
half → Angle
no setter
hashCode → int
The hash code for this object.
no setterinherited
perpendicular → Angle
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sinValue → num
no setter
tanValue → num
no setter
x → num
If used as a vector
no setter
y → num
If used as a vector
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate(Angle theta, [bool anticlockwise = true]) → Angle
toString() → String
A string representation of this object.
inherited

Operators

operator *(num value) → Angle
operator +(Angle angle) → Angle
operator -(Angle angle) → Angle
operator ==(Object other) → bool
The equality operator.
inherited
operator unary-() → Angle