Circle class

Constructors

Circle(Coord center, num radius)
const

Properties

center → Coord
final
flipY → Circle
no setter
hashCode → int
The hash code for this object.
no setterinherited
radius → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromLineAndPoint(Line line, Coord point, num radius) → (Circle, Circle)
Creates 2 circles tangent to the line and passing through point, of given radius.