Corner class

Constructors

Corner(Coord? prev, Coord point, Coord? next, num radius, [Rect? rect, bool inCircle = false])
Provide rect in case the object is bounded inside a box, rect.
Corner.fromList(List<Coord> coords, int index, num radius, [Size? size, bool inCircle = false])
Here provide the size of the Container inside which the figure will be.
factory
Corner.raw(Coord prev, Coord point, Coord next, Circle circle, bool clockwise, bool inCircle)

Properties

circle ↔ Circle
latefinal
clockwise ↔ bool
latefinal
flipY → Corner
no setter
hashCode → int
The hash code for this object.
no setterinherited
inCircle → bool
final
next ↔ Coord
latefinal
point → Coord
final
prev ↔ Coord
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited