Edge class

Constructors

Edge(Coord first, Coord second)
Edge.fromTangent(Corner prev, Corner current)
factory
Edge.sameRadiusDirectTangent(Corner prev, Corner current)
factory

Properties

first → Coord
final
flipY → Edge
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → Coord
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

areCorrectPoints(Coord first, Coord second, Coord center, [bool clockwise = true, num errorTolerance = kDefaultError]) → bool
Set the values of first and second if the tangent is in correct direction, that is clockwise.