Polygon class

Available extensions

Constructors

Polygon(List<Corner> corners, List<Edge> edges, List<num> radii)
Polygon.fromArgs(PolygonArgs args)
factory

Properties

corners ↔ List<Corner>
getter/setter pair
edges ↔ List<Edge>
getter/setter pair
flipY → Polygon
no setter
genPath → Path

Available on Polygon, provided by the PolygonExt extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
radii ↔ List<num>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited