PolygonArgs class

Constructors

PolygonArgs({required List<Coord> coords, List<num>? radii, num radius = kDefaultRadius, Size? size, bool useInCircle = false})
Provide either a single value radius or a list of values for each corner radii.
const

Properties

coords → List<Coord>
final
hashCode → int
The hash code for this object.
no setteroverride
radii → List<num>?
final
radius → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
final
useInCircle → bool
final

Methods

copyWith({List<Coord>? coords, List<num>? radii, num? radius, Size? size, bool? useInCircle}) → PolygonArgs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

kDefaultRadius → const int